# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.9b15] - 2023-06-15
Public beta release 15.
Added binary data from raw_call, and masternode_list_conf

## [0.9b13] - 2023-06-05
Public beta release 13

## [0.9b2] - 2023-06-01
Private beta release 2

## [0.0.1] - 2021-03-08

- Bolivarcoin DAO
  Proposal: [Propuesta DAO a superbloque 764,336 para desarrollo API y APPs periféricas alrededor del núcleo](https://bit.ly/Superbloque764336) 

